aboutsummaryrefslogtreecommitdiffhomepage
path: root/internal/comp.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/comp.go')
-rw-r--r--internal/comp.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/internal/comp.go b/internal/comp.go
index 89dc0f85..28ee6224 100644
--- a/internal/comp.go
+++ b/internal/comp.go
@@ -6,11 +6,11 @@ var (
version = compPoison
)
-// check validates string value set at compile time.
-func check(s string) (string, bool) { return s, s != compPoison && s != "" }
+// checkComp validates string value set at compile time.
+func checkComp(s string) (string, bool) { return s, s != compPoison && s != "" }
func Version() string {
- if v, ok := check(version); ok {
+ if v, ok := checkComp(version); ok {
return v
}
return "impure"